========
Routines
========

A collection of standalone functions for performing various modelling tasks.

.. toctree::
   :maxdepth: 2

   general
   io
   modelling
   matrices
   best_intermediates
   plotting
